<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ky">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>select-area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recording finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quick start</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase height up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase height down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase width left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase width right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start OCR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Arrow</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>GIF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MP4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>webm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>FPS:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>20 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>24 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>30 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System audio</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show click</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text (T)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PNG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>JPG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BMP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Border Effects</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shadow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>